All Classes and Interfaces

Class
Description
An AWS Arn.
Either your AWS credentials are not valid or you do not have access to the EC2 instance.
 
 
 
 
 
 
 
Service client for accessing EC2 Instance Connect asynchronously.
A builder for creating an instance of Ec2InstanceConnectAsyncClient.
 
The parameters object used to resolve the auth schemes for the Ec2InstanceConnect service.
An auth scheme provider for Ec2InstanceConnect service.
This includes configuration specific to EC2 Instance Connect that is supported by both Ec2InstanceConnectClientBuilder and Ec2InstanceConnectAsyncClientBuilder.
Service client for accessing EC2 Instance Connect.
A builder for creating an instance of Ec2InstanceConnectClient.
 
The parameters object used to resolve an endpoint for the Ec2InstanceConnect service.
 
An endpoint provider for Ec2InstanceConnect.
 
 
 
 
 
 
 
 
 
 
 
 
Class to expose the service client settings to the user.
 
The specified instance was not found.
 
Unable to connect because the instance is not in a valid state.
 
The instance type is not supported for connecting via the serial console.
 
The instance is currently unavailable.
 
Link between an endpoint property and the AwsEndpointAttribute it represents.
 
 
Identifiers for variables declared within the rule engine, e.g.
One of the parameters is not valid.
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
Represents a URL to be used internally for endpoint resolution.
 
 
 
 
 
 
 
 
Your account is not authorized to use the EC2 Serial Console.
 
The instance currently has 1 active serial console session.
 
Unable to start a serial console session.
 
Your instance's BIOS version is unsupported for serial console connection.
 
The service encountered an error.
 
 
The requests were made too frequently and have been throttled.
 
 
Base class for the types of values computable by the RuleEngine.
An array value.
A boolean value.
 
 
An integer value.
 
A record (map) value.
A string value.